// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/widgets.dart';
import 'package:wyatt_component_copy_with_extension/component_copy_with_extension.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';

part 'rich_text_builder_component.g.dart';

@ComponentProxyExtension()
abstract class RichTextBuilderComponent extends Component
    with CopyWithMixin<$RichTextBuilderComponentCWProxy> {
  const RichTextBuilderComponent({
    this.text,
    this.parser,
    this.defaultStyle,
    this.styles,
    super.key,
  });

  /// Full text
  final String? text;

  /// How to build InlineSpans
  final RichTextParser? parser;

  /// Default TextStyle used in this rich text component.
  final TextStyle? defaultStyle;

  /// Used styles in this rich text component.
  ///
  /// e.g.
  /// ```dart
  /// styles = {'red': TextStyle(color: Colors.red)};
  /// ```
  /// will transform:
  /// ```text
  /// This text <red>is red</red.
  /// ```
  /// in "This text `is red`."
  final Map<String, TextStyle>? styles;
}
